@@ -20,7 +20,7 @@ use strict;
 use vars qw($VERSION $warnString);
 use Image::ExifTool qw(:DataAccess :Utils);
 
-$VERSION = '1.31';
+$VERSION = '1.32';
 
 sub WarnProc($) { $warnString = $_[0]; }
 
@@ -258,7 +258,7 @@ my %iWorkType = (
 # RAR v5 tags (ref 7, github#203)
 %Image::ExifTool::ZIP::RAR5 = (
     GROUPS => { 2 => 'Other' },
-    VARS => { NO_ID => 1 },
+    VARS => { ID_FMT => 'none' },
     NOTES => 'These tags are extracted from RAR v5 and 7z archive files.',
     FileVersion     => { },
     CompressedSize  => { },
@@ -325,9 +325,13 @@ sub ProcessRAR($$)
             last if $size < 0;
             next unless $size;  # ignore blocks with no data
             # don't try to read very large blocks unless LargeFileSupport is enabled
-            if ($size >= 0x80000000 and not $et->Options('LargeFileSupport')) {
-                $et->Warn('Large block encountered. Aborting.');
-                last;
+            if ($size >= 0x80000000) {
+                if (not $et->Options('LargeFileSupport')) {
+                    $et->Warn('Large block encountered. Aborting.');
+                    last;
+                } elsif ($et->Options('LargeFileSupport') eq '2') {
+                    $et->Warn('Processing large block (LargeFileSupport is 2)');
+                }
             }
             # process the block
             if ($type == 0x74) { # file block
@@ -836,7 +840,7 @@ Electronic Publication (EPUB), and Sketch design files (SKETCH).
 
 =head1 AUTHOR
 
-Copyright 2003-2024, Phil Harvey (philharvey66 at gmail.com)
+Copyright 2003-2025, Phil Harvey (philharvey66 at gmail.com)
 
 This library is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
